@@ -63,7 +63,7 @@ static guint32 last_x_time_stamp = CurrentTime;
 
 static void bonobo_socket_class_init               (BonoboSocketClass    *klass);
 static void bonobo_socket_init                     (BonoboSocket         *socket);
-static void bonobo_socket_destroy                  (GtkObject            *object);
+static void bonobo_socket_finalize                 (GtkObject            *object);
 static void bonobo_socket_realize                  (GtkWidget        *widget);
 static void bonobo_socket_unrealize                (GtkWidget        *widget);
 static void bonobo_socket_size_request             (GtkWidget      *widget,
@@ -127,7 +127,7 @@ bonobo_socket_class_init (BonoboSocketClass *class)
 
 	parent_class = gtk_type_class (GTK_TYPE_CONTAINER);
 
-	object_class->destroy = bonobo_socket_destroy;
+	object_class->finalize = bonobo_socket_finalize;
 
 	widget_class->realize = bonobo_socket_realize;
 	widget_class->unrealize = bonobo_socket_unrealize;
@@ -163,7 +163,7 @@ bonobo_socket_init (BonoboSocket *socket)
 
 /* Destroy handler for the socket */
 static void
-bonobo_socket_destroy (GtkObject *object)
+bonobo_socket_finalize (GtkObject *object)
 {
 	BonoboSocket *socket;
 	BonoboSocketPrivate *priv;
@@ -177,8 +177,8 @@ bonobo_socket_destroy (GtkObject *object)
 	g_free (priv);
 	socket->priv = NULL;
 
-	if (GTK_OBJECT_CLASS (parent_class)->destroy)
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+	if (GTK_OBJECT_CLASS (parent_class)->finalize)
+		(* GTK_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
 /**
@@ -489,7 +489,11 @@ bonobo_socket_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
 	BonoboSocket *socket;
 	BonoboSocketPrivate *priv;
 
+	g_return_val_if_fail (BONOBO_IS_SOCKET (widget), TRUE);
+
 	socket = BONOBO_SOCKET (widget);
+	g_return_val_if_fail (socket->priv != NULL, TRUE);
+
 	priv = socket->priv;
 
 	if (priv->gave_focus && priv->plug_window) {
